/*
 * Copyright 2004-2008 the Seasar Foundation and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
if (typeof(Tugboat.dashboard) == 'undefined') {
    Tugboat.dashboard = {};
}

Tugboat.dashboard = {
  pageOffset   : 1,
  nextPage     : false,
  previousPage : false,
  _isAlreadySearch : false,
  user_modify_window : null,

  /**
   * initialize.
   * 
   */
  initialize : function() {
    Tugboat.dashboard._continuation();
    Tugboat.dashboard._setup_event_rules();
    
    $('search_keyword').value = 'search...';
    
    return false;
  },
  
  /**
   * session continuation.
   */
  _continuation : function() {
    try {
      new Ajax.PeriodicalUpdater(
        '',
        Tugboat.AJAX_SERVLET_NAME,
        {
          method: Tugboat.constant.REQUEST_GET,
          parameters:
          {
            component:'loginAjax',
            action   :'continuation'
          },
          frequency: 300,
          onSuccess: function(transport) {},
          onFailure: function() {
            throw 'continuation error.';
          }
        }
      );
    } catch(e) {
      Tugboat.dashboard._continuation();
    }
  },
  
  _version_info_sub_window : null,
  
  /**
   * get version info.
   */
  _get_version_info : function() {
    new Ajax.Request(
      Tugboat.AJAX_SERVLET_NAME,
      { 
        method: Tugboat.constant.REQUEST_GET,
        parameters:
        {
          component:'applicationCommonAjax',
          action   :'getAboutInfo'
        },
        onComplete: function(transport){
          var version = eval('(' + transport.responseText + ')');
          $('version_info_sub_window_info').innerHTML = 
            'version ' + version.majourNum + '.' + version.minorNum + '.' + version.maintenanceNum;
            
          Tugboat.gtd_task.modal.open();
          var self = Tugboat.dashboard;
            
          self._version_info_sub_window = 
            new Window(
              'versionInfo',
              { className: 'mac_os_x', width:400, height:120, 
                zIndex: 100, 
                minimizable: false, 
                closable   : true, 
                maximizable: false,
                resizable  : false, 
                draggable  : true,
                title      : 'About Tugboat.GTD'
               ,showEffectOptions:{
                  duration:0
                }
              }
            );
          self._version_info_sub_window.setContent('version_info_sub_window_container',false,false);
          self._version_info_sub_window.setDestroyOnClose();
          self._version_info_sub_window.showCenter();
            
          var taskWindowObserver = {
            onDestroy: function(eventName, win) {
              if (win == self._version_info_sub_window) {
                Element.hide('version_info_sub_window_container');
                $('version_info_sub_window_container').appendChild($('version_info_sub_window'));
                           
                Windows.removeObserver(this);
                Tugboat.gtd_task.modal.close();
              }
            }
          };
          Windows.addObserver(taskWindowObserver);
        }
      }
    );
  },
  
  _show_user_info_window : function() {
    var self = Tugboat.dashboard;
    self.user_modify_window = 
      new Window(
        'userModifyWindow',
        { className: 'mac_os_x', width:425, height:220, 
          zIndex: 1000,
          minimizable: false,
          closable   : false,
          maximizable: false,
          resizable  : false,
          draggable  : true,
          title      : 'Edit user info',
          showEffectOptions:{
            duration:0.5,
            afterFinish: function(){
              $('edit_user_password').focus();
            }
          }
        }
      );
    self.user_modify_window.setContent('user_sub_window_container',false,false);
    self.user_modify_window.setDestroyOnClose();
    self.progress.open();
    
    new Ajax.Request(
      Tugboat.AJAX_SERVLET_NAME,
      {
        method: Tugboat.constant.REQUEST_GET,
        parameters:
        {
          component:'userAjax',
          action   :'getUserInfo'
        },
        onComplete: function(transport){
          var user_info = eval('(' + transport.responseText + ')');
          
          $('edit_user_login_id').innerHTML = user_info.loginId;
          $('edit_user_password').value = user_info.password;
          $('edit_user_password_conf').value = user_info.password;
          $('edit_user_family_name').value = user_info.lastName;
          $('edit_user_first_name').value = user_info.firstName;
          $('edit_user_email').value = user_info.email;
          
          self.progress.close();
        }
      }
    );
    self.user_modify_window.showCenter();
    self.modal.open();

    var userWindowObserver = {
      onDestroy: function(eventName, win) {
        if (win == self.user_modify_window) {
          Windows.removeObserver(this);
          $('user_sub_window_container').style.display = 'none';
          
          self.modal.close();
        }
      }
    };
    Windows.addObserver(userWindowObserver);
  },
  
  /**
   * setup event rules.
   */
  _setup_event_rules : function() {
    var rules = {
      '#globalMenuActions input.user_info' : function(el) {
        el.onclick = function(){
          var self = Tugboat.dashboard;
          self._show_user_info_window();
          return false;
        };
      },
      
      '#header_paragraph' : function(el) {
        el.onmouseover = function() {
          el.style.cursor = 'pointer';
        },
        el.onmouseout = function() {
          el.style.cursor = 'default';
        },
        el.onclick = function(){
          var self = Tugboat.dashboard;
          self._show_user_info_window();
          return false;
        };
      },
      
      '#edit_user_cancel_button' : function(el) {
        el.onclick = function() {
          var self = Tugboat.dashboard;
          self.user_modify_window.close();
          return false;
        }
      },
      
      '#edit_user_post_button' : function(el) {
        el.onclick = function() {
          var password = $('edit_user_password').value;
          var password_conf = $('edit_user_password_conf').value;
          var family_name = $('edit_user_family_name').value;
          var first_name = $('edit_user_first_name').value;
          var email = $('edit_user_email').value;
          
          var messages = [];
          if (Tugboat.isEmpty(password))      messages.push('\'Password\' is required.');
          if (Tugboat.isEmpty(password_conf)) messages.push('\'Password again\' is required.');
          if (password != password_conf)      messages.push('\'Password again\' is wrong.');
          if (Tugboat.isEmpty(family_name))   messages.push('\'Family name\' is required.');
          if (Tugboat.isEmpty(first_name))    messages.push('\'First name\' is required.');
          if (Tugboat.isEmpty(email))         messages.push('\'Email\' is required.');
          
          var valid_regexp = /^[^@]+@[^@]+.[a-z]{2,}$/i;
          if (email.search(valid_regexp) == -1) messages.push('A valid e-mail address is required.');
          
          if (messages.length > 0) {
            Tugboat.showAlertDialog( messages );
            return false;
          }
          
          // update invoke.
          var self = Tugboat.dashboard;
          self.progress.open();

          new Ajax.Request(
            Tugboat.AJAX_SERVLET_NAME,
            {
              method: Tugboat.constant.REQUEST_POST,
              parameters:
              {
                component : 'userAjax',
                action    : 'update',
                password  : password,
                email     : email,
                lastName  : family_name,
                firstName : first_name
              },
              onComplete : function(transport){
                $('header_user_info').innerHTML = family_name + ',' + first_name;
                self.user_modify_window.close();
                self.progress.close();
              },
              onFailure : function(transport) {
                self.progress.close();
              }
            }
          );
          return false;
        }
      },
      
      '#globalMenuActions input.search_icon' : function(el) {
        el.onclick = function(){
          $('globalSearch').style.display='block';
          el.blur();
          
          $('search_keyword').focus();
          return false;
        };
      },
      '#globalSearch a.close_icon' : function(el) {
        el.onclick = function() {
          $('globalSearch').style.display='none'; 
          $('modal_window').style.display = 'none';
          el.blur();
          
          //$('modal_window').style.display = 'none';
          return false;
        }
      },
      '#globalSearch a.close_icon_xs' : function(el) {
        el.onclick = function() {
          $('search_keyword').value = '';
          $('search_result_page_info').style.display='none';
          $('search_results').style.display='none';
          $('modal_window').style.display = 'none';
          el.blur();
          
          $('search_keyword').focus();
          $('globalSearchResultBody').style.height = 'auto';
          return false;
        }
      },
      '#globalSearchForm' : function(el) {
        el.onsubmit = function() {
          var self = Tugboat.dashboard;
          if (self._isAlreadySearch) return false;
          var keyword = $('search_keyword').value;
  	      if ( Tugboat.isEmpty(keyword) ) {
  		    return false;
  	      }
          self._isAlreadySearch = true;
          Tugboat.dashboard.resizeSearchResultBody();
          Tugboat.dashboard.pageOffset = '1';
          Tugboat.dashboard.clearKeywords();
          Tugboat.dashboard.keywordSearch(keyword);
          return false;
        }
      },
      '#search_page_prev' : function(el) {
        el.onclick = function() {
          if (el.className.indexOf('off') > -1) return false;
          Tugboat.dashboard.pageOffset-- ;
          Tugboat.dashboard.clearKeywords();
          Tugboat.dashboard.keywordSearch($('search_keyword').value);
          return false;
        }
      },
      '#search_page_next' : function(el) {
        el.onclick = function() {
          if (el.className.indexOf('off') > -1) return false;
          Tugboat.dashboard.pageOffset++ ;
          Tugboat.dashboard.clearKeywords();
          Tugboat.dashboard.keywordSearch($('search_keyword').value);
          return false;
        }
      },
      '#search_keyword' : function(el) {
        el.onfocus = function() {
          if ('search...' == el.value) {
            el.value = '';
          }
        },
        el.onblur = function() {
          if (Tugboat.isEmpty(el.value)) {
            el.value = 'search...';
          }
        }
      }
    };
    Behaviour.register(rules);
    return false;
  },
  
  /**
   * resize search result body.
   */
  resizeSearchResultBody : function() {
	var window_size = Tugboat.getPageSize();
    var elGtdListPane = YAHOO.util.Dom.getRegion('globalSearchResultBody');
    
    var height = 
      window_size.windowHeight 
      - elGtdListPane.top
      - 10;
    
    $('globalSearchResultBody').style.height = height+'px';
    $('search_results').style.height = (height - 50) + 'px';
    return false;
  },
  
  /**
   * keyword search.
   * 
   * @param {String} keywordS
   */
  keywordSearch : function(keyword) {
  	new Ajax.Request(
      Tugboat.AJAX_SERVLET_NAME,
      {
        method:Tugboat.constant.REQUEST_POST,
        parameters:
        {
          component:'searcherAjax',
          action   :'keywordSearch',
          keyword  :keyword,
          offset   :Tugboat.dashboard.pageOffset
        },
        onComplete:  function(transport) {
          var  jsonValue = eval( '(' + transport.responseText + ')' );
          
          $('search_count').innerHTML = jsonValue.search_count;
          $('page_offset').innerHTML = jsonValue.page_offset;
          $('total_page').innerHTML = jsonValue.total_page;

          var resultsTask = jsonValue.task;
          var searchResultsTask = resultsTask.collect(
            function(value, index) {
              var pbody = P(null);
              pbody.innerHTML = value.body; 
              return (
                LI(null,
                  [ P({'class':'title'}, 
                    A( {'href':'gtdTaskDetail.html?id=' + value.dataID + (value.dataLevel > 0 ? '&commentId=' + value.dataLevel : '') }, value.title) ),
                    pbody,
                    P({'class':'Limit'}, value.modified ),
                    P({'class':'posted'}, value.userName )
                  ]
                )
              )
            }
          );
          appendChildNodes("search_results_task", searchResultsTask); 
          
          var resultsMeeting = jsonValue.meeting;
          var searchResultsMeeting = resultsMeeting.collect(
            function(value, index) {
              var pbody = P(null);
              pbody.innerHTML = value.body; 
              return (
                LI(null,
                  [ P({'class':'title'}, 
                    A( {'href':'gtdMeetingDetail.html?id=' + value.dataID }, value.title) ),
                    pbody,
                    P({'class':'Limit'}, value.modified ),
                    P({'class':'posted'}, value.userName )
                  ]
                )
              )
            }
          );
          appendChildNodes("search_results_meeting", searchResultsMeeting); 
         
          $('search_result_page_info').style.display='block';
          $('search_results').style.display='block';
          
          var page = Tugboat.getPageSize(); 
          Element.setHeight('modal_window', page.pageHeight);
          //$('modal_window').style.display = 'block';

          Tugboat.dashboard.nextPage     = jsonValue.next_page;
          if (Tugboat.dashboard.nextPage) {
            $('search_page_next').className = 'page_next';
          }    else {
            $('search_page_next').className = 'page_next_off';
          }
          Tugboat.dashboard.previousPage = jsonValue.previous_page;
          if (Tugboat.dashboard.previousPage) {
            $('search_page_prev').className = 'page_prev';
          }    else {
            $('search_page_prev').className = 'page_prev_off';
          }
         
          var self = Tugboat.dashboard;
          self._isAlreadySearch = false;
          
          return false;
        }
      }
    );
  },

  /**
   * clear keywords.
   * @param {String} keywordS
   */
  clearKeywords : function() {
    $('search_count').innerHTML = '0';
    $('page_offset').innerHTML = '0';
    $('total_page').innerHTML = '0';

    $('search_results_task').innerHTML = '';
    $('search_results_meeting').innerHTML = '';
    return false;
  },

  /**
   * close window on click.
   */
  closeWindow_onclick : function() {
  	var targetElement = document.getElementById('navigation_search_result');
	targetElement.style.display = 'none';
    return false;
  },
  
  modal : {
    _is_opened : false,
    
    open : function () {
      Tugboat.dashboard.modal._is_opened = true;
      var page = Tugboat.getPageSize(); 
      Element.setHeight('modal_window', page.pageHeight);
      $('modal_window').style.display = Tugboat.constant.STYLE_DISPLAY_BLOCK;
    },

    close : function() {
      Tugboat.dashboard.modal._is_opened = false;
      Element.hide('modal_window');
    }
  },

  progress : {
    _is_processing : false,
    
    open : function () {
      var self = Tugboat.dashboard.progress;
      if (self._is_processing) return false;
      self._is_processing = true;
      
      var page = Tugboat.getPageSize(); 
      Element.setHeight('progress_window', page.pageHeight);
      $('progress_window').style.display = Tugboat.constant.STYLE_DISPLAY_BLOCK;
    },
    close : function() {
      Tugboat.dashboard.progress._is_processing = false;
      Element.hide('progress_window');
    }
  }
};
YAHOO.util.Event.addListener(
  'search_keyword', "keydown",
  function(key){
    if (key.keyCode == Event.KEY_ESC) {
      $('globalSearch').style.display = 'none';
    }
  }
);